# Pandora Intelligence Log decorators
Enables users to add decorators to specific functions
- logs
  - log_duration
  - log_exception
  - log_memory
  - log_memory_extensive
  - log_on_end
  - log_on_error
  - log_on_start
- utils
  - copy_docstring_of
  
# based on 
https://pypi.org/project/logdecorator/ \
https://pypi.org/project/guppy3/ \
https://chase-seibert.github.io/blog/2013/08/03/diagnosing-memory-leaks-python.html \
https://github.com/pythonprofilers/memory_profiler/tree/e43d78bf6d58d5f32c1f4f4ace5b371805351eee \
https://towardsdatascience.com/using-class-decorators-in-python-2807ef52d273

# additions
- null decorators
- tags for querying besides log level
- store in database 
- wrap doctstrings  